==> monggregate-0.9.0-py3-none-any.whl: monggregate/base.py <==
"""Module defining the base class of the package"""

# Standard Library imports
#----------------------------
from abc import ABC, abstractmethod
from typing import Any

# 3rd Party imports
# ---------------------------
from pydantic import BaseModel as PydanticBaseModel, BaseConfig, validator

class BaseModel(PydanticBaseModel, ABC):
    """Mongreggate base class"""

    @validator("*", pre=True)
    @classmethod
    def resolve(cls, expression:Any)->dict|list[dict]:
        """Resolves an expression encapsulated in an object from a class inheriting from BaseModel"""

        def isbasemodel(instance:Any)->bool:
            """Returns true if instance is an instance of BaseModel"""

            return isinstance(instance, BaseModel)

        if isbasemodel(expression):
            output:dict|list = expression.statement
        elif isinstance(expression, list) and any(map(isbasemodel, expression)):
            output = []
            for element in expression:
                if isinstance(element, BaseModel):
                    output.append(element.statement)
                else:
                    output.append(element)
        #elif isinstance(expression, dict): # Does this case really exist ?
        else:
            output = expression

        return output

    @property
    @abstractmethod
    def statement(self)->dict:
        """Stage statement absctract method"""

        # this is a lazy attribute
        # what is currently in generate statement should go in here


    def __call__(self)->dict:
        """Makes an instance of any class inheriting from this class callable"""

        return self.statement

    class Config(BaseConfig):
        """Base configuration for classes inheriting from this"""

        allow_population_by_field_name = True
        underscore_attrs_are_private = True

==> monggregate-0.12.0-py3-none-any.whl: monggregate/base.py <==
"""Module defining the base class of the package"""

# Standard Library imports
#----------------------------
from abc import ABC, abstractmethod
from typing import Any

# 3rd Party imports
# ---------------------------
from pydantic import BaseModel as PydanticBaseModel, BaseConfig
from humps import camelize

class BaseModel(PydanticBaseModel, ABC):
    """Mongreggate base class"""

    @classmethod
    def resolve(cls, obj:Any)->dict|list[dict]:
        """Resolves an expression encapsulated in an object from a class inheriting from BaseModel"""

        return resolve(obj)

    @property
    @abstractmethod
    def statement(self)->dict:
        """Stage statement absctract method"""

        # this is a lazy attribute
        # what is currently in generate statement should go in here

    def __call__(self)->dict:
        """Makes an instance of any class inheriting from this class callable"""

        return self.statement

    class Config(BaseConfig):
        """Base configuration for classes inheriting from this"""

        allow_population_by_field_name = True
        underscore_attrs_are_private = True
        alias_generator = camelize


def isbasemodel(instance:Any)->bool:
    """Returns true if instance is an instance of BaseModel"""

    return isinstance(instance, BaseModel)

def resolve(obj:Any)->dict|list[dict]:
        """Resolves an expression encapsulated in an object from a class inheriting from BaseModel"""

        if isbasemodel(obj):
            output:dict|list = obj.statement
        elif isinstance(obj, list) and any(map(isbasemodel, obj)):
            output = []
            for element in obj:
                if isinstance(element, BaseModel):
                    output.append(element.statement)
                else:
                    output.append(element)
        elif isinstance(obj, dict):
            output = {}
            for key, value in obj.items():
                if isinstance(value, BaseModel):
                    output[key] = value.statement
                else:
                    output[key] = resolve(value)
        else:
            output = obj

        return output
